@@ -3,10 +3,12 @@ use strict;
 
 package Mail::Box::Locker::File;
 use Mail::Box::Locker;
-our @ISA = 'Mail::Box::Locker';
+use vars '@ISA';
+@ISA = 'Mail::Box::Locker';
 
 use Fcntl         qw/:DEFAULT :flock/;
 use IO::File;
+use Errno         qw/EAGAIN/;
 
 # For documentation, see Mail::Box::Locker
 
@@ -36,6 +38,11 @@ sub lock()
             return 1;
         }
 
+        if($! != EAGAIN)
+        {   warn "Will never get a lock at ".$self->{MBL_folder}->name.": $!\n";
+            return 0;
+        }
+
         sleep 1;
         $timer++;
     }
